==> generator-efigence-0.2.0.tgz: package/app/templates/gulpfile.js <==
var gulp = require('gulp');
var sourcemaps = require('gulp-sourcemaps');
var plumber = require('gulp-plumber');
var connect = require('gulp-connect');
var concat = require('gulp-concat');
var jasmine = require('gulp-jasmine');
var sass = require('gulp-sass');

var config = require('./config.json');

// var cssnano = require('cssnano');
// var uglify = require('gulp-uglify');
// var fileinclude = require('gulp-file-include');
// var prettify = require('gulp-prettify');
// var $ = require('gulp-load-plugins')();

function handleError(err) {
    
    console.log("ERROR: " + err);
}

gulp.task('styles', function () {
    gulp.src('src/styles/*.scss')
        .pipe(sass().on('error', sass.logError))
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('public/css'))
        .on('error', handleError)
        .pipe(connect.reload());
});

gulp.task('scripts', function () {
    gulp.src('src/js/*.js')
        .pipe(plumber(handleError))
        .pipe(concat('app.js'))
        .on('error', handleError)
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('public/js'))
        .pipe(connect.reload());
});

gulp.task('img', function () {
    return gulp.src([
            'src/img/*'
        ])
        .pipe(gulp.dest('public/img'))
        .pipe(connect.reload());
});

gulp.task('html', function () {
    return gulp.src([
            'src/index.html'
        ])
        .pipe(gulp.dest('public/'))
        .pipe(connect.reload());
});

gulp.task('jasmine', function () {
    return gulp.src('src/tests/test.js')
        // gulp-jasmine works on filepaths so you can't have any plugins before it 
        .pipe(jasmine());
});

gulp.task('watch', ['build', 'connect'], function () {

    // UGLY code, todo: rewrite:

    for(var index in config.tasks) { 
       
       if (config.tasks.hasOwnProperty(index)) {
       
           gulp.watch(config.tasks[index], [index]);
       }
    }
});

gulp.task('connect', function () {
    connect.server({
        root: ['public'],
        port: 8080,
        livereload: true
    })
});

gulp.task('build', function () {

    gulp.run(Object.keys(config.tasks));
});

gulp.task('default', function () {

    gulp.run(['build', 'watch']);
});


// gulp.task('fileinclude', function () {
//  return gulp.src(['src/index.html'])
//      .pipe(fileinclude({
//          prefix: '@@',
//          basepath: '@file'
//      }))
//      .pipe(gulp.dest('./public'))
//      .pipe(connect.reload());
// });
// gulp.task('prettify', ['fileinclude'], function () {
//  return gulp.src('public/*.html')
//      .pipe(prettify({indent_size: 2}))
//      .pipe(gulp.dest('public'))
//      .pipe(connect.reload());
// });

// gulp.task('clean', function() {
//     gulp.src('public/*', {read: false})
//         .pipe(clean({force: true}));
// })

// gulp.task('minify', function() {

//     gulp.run(['minify:styles', 'minify:scripts'])
// });

==> generator-efigence-0.2.1.tgz: package/app/templates/gulpfile.js <==
var gulp            = require('gulp');
var sourcemaps      = require('gulp-sourcemaps');
var plumber         = require('gulp-plumber');
var connect         = require('gulp-connect');
var concat          = require('gulp-concat');
var jasmine         = require('gulp-jasmine');
var sass            = require('gulp-sass');
var merge           = require('merge-stream');
var kss             = require('kss');
var config          = require('./config.json');
var cmq             = require('gulp-group-css-media-queries');
var autoprefixer    = require('gulp-autoprefixer');

var autoprefixerParams = {
        browsers: ['> 5%','last 2 versions'],
        cascade: false
    };

// var cssnano = require('cssnano');
// var uglify = require('gulp-uglify');
// var fileinclude = require('gulp-file-include');
// var prettify = require('gulp-prettify');
// var $ = require('gulp-load-plugins')();

function handleError(err) {
    
    console.log("ERROR: " + err);
}

gulp.task('styles', function () {
    gulp.src('src/css/*.scss')
        .pipe(sass().on('error', sass.logError))
        .pipe($.autoprefixer(autoprefixerParams))
        .pipe(cmq())
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('public/css'))
        .on('error', handleError)
        .pipe(connect.reload());
});

gulp.task('scripts', function () {
    gulp.src('src/js/*.js')
        .pipe(plumber(handleError))
        .pipe(concat('app.js'))
        .on('error', handleError)
        .pipe(sourcemaps.write())
        .pipe(gulp.dest('public/js'))
        .pipe(connect.reload());
});

// gulp.task('kss', function(){

//     gulp.src('src/css/*.scss')
//     .pipe(gulpkss({
//         overview: __dirname + '/styles/styleguide.md'
//     }))
//     .pipe(gulp.dest('styleguide/'));
// });

gulp.task('img', function () {
    return gulp.src([
            'src/images/*'
        ])
        .pipe(gulp.dest('public/images'))
        .pipe(connect.reload());
});

gulp.task('html', function () {
    return gulp.src([
            'src/index.html'
        ])
        .pipe(gulp.dest('public/'))
        .pipe(connect.reload());
});

gulp.task('vendors',function(){

    var foundationJS = gulp.src(["node_modules/foundation/js/foundation/*"])
        .pipe(gulp.dest('src/js/vendor/foundation'));

    var foundationCSS = gulp.src(["node_modules/foundation/scss/*"])
        .pipe(gulp.dest('src/css/vendor/foundation'));    

    var jquery = gulp.src('node_modules/jquery/dist/*')
        .pipe(gulp.dest('src/js/vendor/jquery'));

    return merge(foundationJS, foundationCSS, jquery);
});

gulp.task('jasmine', function () {
    return gulp.src('src/tests/test.js')
        // gulp-jasmine works on filepaths so you can't have any plugins before it 
        .pipe(jasmine());
});

gulp.task('watch', ['build', 'connect'], function () {

    // UGLY code, todo: rewrite:

    for(var index in config.tasks) { 
       
       if (config.tasks.hasOwnProperty(index)) {
       
           gulp.watch(config.tasks[index], [index]);
       }
    }
});

gulp.task('connect', function () {
    connect.server({
        root: ['public'],
        port: 8080,
        livereload: true
    })
});

gulp.task('build', function () {
    
    gulp.run(Object.keys(config.tasks));
});

gulp.task('default', function () {

    gulp.run(['vendors','build', 'watch']);
});

// gulp.task('fileinclude', function () {
//  return gulp.src(['src/index.html'])
//      .pipe(fileinclude({
//          prefix: '@@',
//          basepath: '@file'
//      }))
//      .pipe(gulp.dest('./public'))
//      .pipe(connect.reload());
// });
// gulp.task('prettify', ['fileinclude'], function () {
//  return gulp.src('public/*.html')
//      .pipe(prettify({indent_size: 2}))
//      .pipe(gulp.dest('public'))
//      .pipe(connect.reload());
// });

// gulp.task('clean', function() {
//     gulp.src('public/*', {read: false})
//         .pipe(clean({force: true}));
// })

// gulp.task('minify', function() {

//     gulp.run(['minify:styles', 'minify:scripts'])
// });
